@@ -13,6 +13,7 @@ APS Machine Parameters
 from ophyd import Component
 from ophyd import Device
 from ophyd import EpicsSignalRO
+
 from .aps_cycle import ApsCycleDM
 
 
@@ -53,7 +54,7 @@ class ApsMachineParametersDevice(Device):
         # db[-1].table("aps_current_monitor")
         sd.monitors.append(aps_current)
 
-    The `sd.baseline` and `sd.monitors` usage relies on this global setup:
+    The `sd.baseline` and `sd.monitors` usage relies on this global setup::
 
         from bluesky import SupplementalData
         sd = SupplementalData()
@@ -122,13 +123,12 @@ class ApsMachineParametersDevice(Device):
         )
         # fmt: on
 
-
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
+# :copyright: (c) 2017-2023, UChicago Argonne, LLC
 #
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
+# Distributed under the terms of the Argonne National Laboratory Open Source License.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 # -----------------------------------------------------------------------------
