@@ -10,23 +10,16 @@ Public Structures
     ~EpicsRecordInputFields
     ~EpicsRecordOutputFields
     ~EpicsRecordFloatFields
+    ~EpicsSynAppsRecordEnableMixin
 
 :see: https://wiki-ext.aps.anl.gov/epics/index.php/RRM_3-14_dbCommon
 :see: https://wiki-ext.aps.anl.gov/epics/index.php/RRM_3-14_Common
 """
 
-# -----------------------------------------------------------------------------
-# :author:    Pete R. Jemian
-# :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
-#
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# -----------------------------------------------------------------------------
-
-from ophyd.device import Device, Component
-from ophyd import EpicsSignal, EpicsSignalRO
+from ophyd import EpicsSignal
+from ophyd import EpicsSignalRO
+from ophyd.device import Component
+from ophyd.device import Device
 
 
 class EpicsRecordDeviceCommonAll(Device):
@@ -114,3 +107,23 @@ class EpicsRecordFloatFields(Device):
     low_alarm_severity = Component(EpicsSignal, ".LSV", kind="config")
     lolo_alarm_severity = Component(EpicsSignal, ".LLSV", kind="config")
     alarm_hysteresis = Component(EpicsSignal, ".HYST", kind="config")
+
+
+class EpicsSynAppsRecordEnableMixin(Device):
+    """Supports ``{PV}Enable`` feature from user databases."""
+    enable = Component(EpicsSignal, "Enable", kind="config")
+
+    def reset(self):
+        """set all fields to default values"""
+        self.enable.put(self.enable.enum_strs[1])  # Enable
+        super().reset()
+
+# -----------------------------------------------------------------------------
+# :author:    Pete R. Jemian
+# :email:     jemian@anl.gov
+# :copyright: (c) 2017-2023, UChicago Argonne, LLC
+#
+# Distributed under the terms of the Argonne National Laboratory Open Source License.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+# -----------------------------------------------------------------------------
