@@ -8,22 +8,24 @@ Public Structures
 .. autosummary::
 
     ~UserScalcoutDevice
+    ~UserScalcoutN
     ~ScalcoutRecord
     ~ScalcoutRecordNumberChannel
     ~ScalcoutRecordStringChannel
 """
 
 from collections import OrderedDict
+
 from ophyd import Component as Cpt
 from ophyd import Device
 from ophyd import DynamicDeviceComponent as DDC
 from ophyd import EpicsSignal
 from ophyd import FormattedComponent as FC
 
+from .. import utils as APS_utils
 from ._common import EpicsRecordDeviceCommonAll
 from ._common import EpicsRecordFloatFields
-from .. import utils as APS_utils
-
+from ._common import EpicsSynAppsRecordEnableMixin
 
 CHANNEL_LETTERS_LIST = "A B C D E F G H I J K L".split()
 
@@ -39,7 +41,7 @@ class ScalcoutRecordNumberChannel(Device):
         ~reset
     """
 
-    input_value = FC(EpicsSignal, "{prefix}.{_ch}", kind="hinted")
+    input_value = FC(EpicsSignal, "{prefix}.{_ch}", kind="config")
     input_pv = FC(EpicsSignal, "{prefix}.INP{_ch}", kind="config")
 
     def __init__(self, prefix, letter, **kwargs):
@@ -63,7 +65,7 @@ class ScalcoutRecordStringChannel(Device):
         ~reset
     """
 
-    input_value = FC(EpicsSignal, "{prefix}.{_ch}", kind="hinted")
+    input_value = FC(EpicsSignal, "{prefix}.{_ch}", kind="config")
     input_pv = FC(EpicsSignal, "{prefix}.IN{_ch}", kind="config")
 
     def __init__(self, prefix, letter, **kwargs):
@@ -98,8 +100,6 @@ class ScalcoutRecord(EpicsRecordFloatFields, EpicsRecordDeviceCommonAll):
 
     :see: http://htmlpreview.github.io/?https://github.com/epics-modules/calc/blob/R3-6-1/documentation/calcDocs.html
     """
-    enable = Cpt(EpicsSignal, "Enable", kind="omitted")
-
     units = Cpt(EpicsSignal, ".EGU", kind="config")
     precision = Cpt(EpicsSignal, ".PREC", kind="config")
 
@@ -108,7 +108,7 @@ class ScalcoutRecord(EpicsRecordFloatFields, EpicsRecordDeviceCommonAll):
     calculated_value_string = Cpt(EpicsSignal, ".SVAL", kind="normal")
 
     output_calculation = Cpt(EpicsSignal, ".OCAL", kind="config", string=True)
-    output_value = Cpt(EpicsSignal, ".OVAL", kind="hinted")
+    output_value = Cpt(EpicsSignal, ".OVAL", kind="config")
     output_value_string = Cpt(EpicsSignal, ".OSV", kind="hinted", string=True)
     output_pv = Cpt(EpicsSignal, ".OUT", kind="config")
     output_execute_option = Cpt(EpicsSignal, ".OOPT", kind="config")
@@ -175,6 +175,10 @@ class ScalcoutRecord(EpicsRecordFloatFields, EpicsRecordDeviceCommonAll):
         self.hints = {"fields": self.read_attrs}
 
 
+class UserScalcoutN(EpicsSynAppsRecordEnableMixin, ScalcoutRecord):
+    """Single instance of the userStringCalcN database."""
+
+
 class UserScalcoutDevice(Device):
     """
     EPICS synApps XXX IOC setup of user scalcouts: ``$(P):userStringCalc$(N)``
@@ -188,16 +192,16 @@ class UserScalcoutDevice(Device):
     """
 
     enable = Cpt(EpicsSignal, "userStringCalcEnable", kind="omitted")
-    scalcout1 = Cpt(ScalcoutRecord, "userStringCalc1")
-    scalcout2 = Cpt(ScalcoutRecord, "userStringCalc2")
-    scalcout3 = Cpt(ScalcoutRecord, "userStringCalc3")
-    scalcout4 = Cpt(ScalcoutRecord, "userStringCalc4")
-    scalcout5 = Cpt(ScalcoutRecord, "userStringCalc5")
-    scalcout6 = Cpt(ScalcoutRecord, "userStringCalc6")
-    scalcout7 = Cpt(ScalcoutRecord, "userStringCalc7")
-    scalcout8 = Cpt(ScalcoutRecord, "userStringCalc8")
-    scalcout9 = Cpt(ScalcoutRecord, "userStringCalc9")
-    scalcout10 = Cpt(ScalcoutRecord, "userStringCalc10")
+    scalcout1 = Cpt(UserScalcoutN, "userStringCalc1")
+    scalcout2 = Cpt(UserScalcoutN, "userStringCalc2")
+    scalcout3 = Cpt(UserScalcoutN, "userStringCalc3")
+    scalcout4 = Cpt(UserScalcoutN, "userStringCalc4")
+    scalcout5 = Cpt(UserScalcoutN, "userStringCalc5")
+    scalcout6 = Cpt(UserScalcoutN, "userStringCalc6")
+    scalcout7 = Cpt(UserScalcoutN, "userStringCalc7")
+    scalcout8 = Cpt(UserScalcoutN, "userStringCalc8")
+    scalcout9 = Cpt(UserScalcoutN, "userStringCalc9")
+    scalcout10 = Cpt(UserScalcoutN, "userStringCalc10")
 
     def reset(self):  # lgtm [py/similar-function]
         """set all fields to default values"""
@@ -217,9 +221,9 @@ class UserScalcoutDevice(Device):
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
+# :copyright: (c) 2017-2023, UChicago Argonne, LLC
 #
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
+# Distributed under the terms of the Argonne National Laboratory Open Source License.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 # -----------------------------------------------------------------------------
