@@ -1,24 +1,32 @@
+import time
+
 import pytest
 
-from ..iocstats import IocStatsDevice
 from ...tests import IOC
+from ...tests import common_attribute_quantities_test
+from ...tests import timed_pause
+from ..iocstats import IocStatsDevice
 
 
-def test_read():
-    gp_info = IocStatsDevice(IOC, name="gp_info")
-    gp_info.wait_for_connection()
-    assert gp_info.connected
-
-    assert len(gp_info.read_attrs) == 19
-    assert len(gp_info.configuration_attrs) == 8
-    assert len(gp_info._summary().splitlines()) == 73
+@pytest.mark.parametrize(
+    "device, pv, connect, attr, expected",
+    [
+        [IocStatsDevice, IOC, False, "read_attrs", 19],
+        [IocStatsDevice, IOC, False, "configuration_attrs", 8],
+        [IocStatsDevice, IOC, True, "read()", 19],
+        [IocStatsDevice, IOC, True, "summary()", 73],
+    ]
+)
+def test_attribute_quantities(device, pv, connect, attr, expected):
+    """Verify the quantities of the different attributes."""
+    common_attribute_quantities_test(device, pv, connect, attr, expected)
 
 
 @pytest.mark.parametrize(
     "attr, expected, comparison",
     [
         ["access", "Running", None],
-        ["application_directory", "iocxxx", "end"],
+        # TODO: ["application_directory", "iocxxx", "end"],
         ["engineer", "engineer", None],
         ["epics_version", "EPICS", "start"],
         ["kernel_version", "Linux", "start"],
@@ -31,9 +39,11 @@ def test_running(attr, expected, comparison):
     gp_info = IocStatsDevice(IOC, name="gp_info")
     gp_info.wait_for_connection()
     assert gp_info.connected
+    timed_pause()
 
     assert hasattr(gp_info, attr)
-    value = getattr(gp_info, attr).get()
+    value = getattr(gp_info, attr).get(use_monitor=False)
+    time.sleep(.1)
     if comparison == "start":
         assert value.startswith(expected)
     elif comparison == "end":
@@ -44,13 +54,3 @@ def test_running(attr, expected, comparison):
         assert value >= 0
     else:
         assert value == expected
-
-# -----------------------------------------------------------------------------
-# :author:    Pete R. Jemian
-# :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
-#
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# -----------------------------------------------------------------------------
