@@ -1,11 +1,10 @@
 import pytest
-import time
 
+from ...tests import IOC
+from ...tests import common_attribute_quantities_test
+from ...tests import timed_pause
 from ..luascript import LuascriptRecord
 from ..luascript import UserScriptsDevice
-from ...tests import IOC
-from ...tests import SHORT_DELAY_FOR_EPICS_IOC_DATABASE_PROCESSING
-
 
 PV_PREFIX = f"{IOC}set1:"
 EMPIRICAL_DELAY = 0.5
@@ -16,28 +15,36 @@ EMPIRICAL_DELAY = 0.5
 # https://epics-lua.readthedocs.io/en/latest/using-lua-shell.html?highlight=file#calling-the-lua-shell-from-inside-the-ioc-shell
 
 
-def test_read():
-    lua = LuascriptRecord(f"{PV_PREFIX}userScript9", name="lua")
-    assert lua is not None
-    # lua.wait_for_connection()
+@pytest.mark.parametrize(
+    "device, pv, connect, attr, expected",
+    [
+        [LuascriptRecord, f"{PV_PREFIX}userScript9", False, "read_attrs", 10],
+        [LuascriptRecord, f"{PV_PREFIX}userScript9", False, "configuration_attrs", 98],
+        [LuascriptRecord, f"{PV_PREFIX}userScript9", True, "read()", 2],
+        [LuascriptRecord, f"{PV_PREFIX}userScript9", True, "summary()", 207],
 
-    assert len(lua.read_attrs) == 10
-    assert len(lua.configuration_attrs) == 78
-    assert len(lua._summary().splitlines()) == 187
+        [UserScriptsDevice, PV_PREFIX, False, "read_attrs", 110],
+        [UserScriptsDevice, PV_PREFIX, False, "configuration_attrs", 991],
+        [UserScriptsDevice, PV_PREFIX, True, "read()", 20],
+        [UserScriptsDevice, PV_PREFIX, True, "summary()", 1906],
+    ]
+)
+def test_attribute_quantities(device, pv, connect, attr, expected):
+    """Verify the quantities of the different attributes."""
+    common_attribute_quantities_test(device, pv, connect, attr, expected)
 
 
 def test_luascript_reset():
     lua_all = UserScriptsDevice(PV_PREFIX, name="user")
     lua_all.wait_for_connection()
     lua_all.enable.put("Enable")
-    assert len(lua_all.read()) == 220
 
     lua = lua_all.script9
     assert isinstance(lua, LuascriptRecord)
 
     lua_all.reset()
     lua.disable_value.put(2)  # ensure record is always enabled
-    time.sleep(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
+    timed_pause(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
     assert (
         lua.scan_disable_input_link_value.get() != lua.disable_value.get()
     )
@@ -58,7 +65,7 @@ def test_luascript_reset():
     lua.inputs.BB.input_value.put("BB.input_value")
     # order is important, set this LAST
     lua.code.put("code")
-    time.sleep(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
+    timed_pause(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
 
     assert lua.precision.get() != 5
     assert lua.code.get() != ""
@@ -69,6 +76,7 @@ def test_luascript_reset():
     assert lua.inputs.BB.input_value.get() != ""
 
     lua_all.reset()
+    timed_pause()
 
     assert lua.precision.get() == 5
     assert lua.code.get() == ""
@@ -100,10 +108,11 @@ def test_compute(code, a, b, nval, aa, bb, sval):
     lua_all = UserScriptsDevice(PV_PREFIX, name="user")
     lua_all.wait_for_connection()
     lua_all.enable.put("Enable")
-    time.sleep(SHORT_DELAY_FOR_EPICS_IOC_DATABASE_PROCESSING)
+    timed_pause()
     assert lua_all.enable.get(as_string=True) == "Enable"
 
     lua_all.reset()
+    timed_pause()
 
     lua = lua_all.script9
     lua.disable_value.put(2)  # ensure record is always enabled
@@ -126,19 +135,10 @@ def test_compute(code, a, b, nval, aa, bb, sval):
 
     # do the computation
     lua.process_record.put(1)
-    time.sleep(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
+    timed_pause(EMPIRICAL_DELAY)  # a short-ish wait (discovered empirically)
 
     assert round(lua.number_value.get(), 5) == nval
     assert lua.string_value.get() == sval
 
-    lua.reset()
-
-# -----------------------------------------------------------------------------
-# :author:    Pete R. Jemian
-# :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
-#
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# -----------------------------------------------------------------------------
+    lua_all.reset()
+    timed_pause()
