@@ -1,31 +1,41 @@
-import time
+import pytest
 
+from ...tests import IOC
+from ...tests import common_attribute_quantities_test
+from ...tests import timed_pause
 from ..scalcout import ScalcoutRecord
 from ..scalcout import UserScalcoutDevice
-from ...tests import IOC
-from ...tests import SHORT_DELAY_FOR_EPICS_IOC_DATABASE_PROCESSING
 
 
-def test_read():
-    scalcout = ScalcoutRecord(f"{IOC}userStringCalc10", name="scalcout")
-    assert scalcout is not None
-    scalcout.wait_for_connection()
+@pytest.mark.parametrize(
+    "device, pv, connect, attr, expected",
+    [
+        [ScalcoutRecord, f"{IOC}userStringCalc10", False, "read_attrs", 24],
+        [ScalcoutRecord, f"{IOC}userStringCalc10", False, "configuration_attrs", 114],
+        [ScalcoutRecord, f"{IOC}userStringCalc10", True, "read()", 3],
+        [ScalcoutRecord, f"{IOC}userStringCalc10", True, "summary()", 250],
 
-    assert len(scalcout.read_attrs) == 24
-    assert len(scalcout.configuration_attrs) == 89
-    assert len(scalcout._summary().splitlines()) == 227
+        [UserScalcoutDevice, IOC, False, "read_attrs", 250],
+        [UserScalcoutDevice, IOC, False, "configuration_attrs", 1160],
+        [UserScalcoutDevice, IOC, True, "read()", 30],
+        [UserScalcoutDevice, IOC, True, "summary()", 2355],
+    ]
+)
+def test_attribute_quantities(device, pv, connect, attr, expected):
+    """Verify the quantities of the different attributes."""
+    common_attribute_quantities_test(device, pv, connect, attr, expected)
 
 
 def test_scalcout_reset():
     user = UserScalcoutDevice(IOC, name="user")
     user.wait_for_connection()
     user.enable.put("Enable")
-    assert len(user.read()) == 280
 
     calc = user.scalcout10
     assert isinstance(calc, ScalcoutRecord)
 
     calc.reset()
+    timed_pause()
     assert calc.enable.get() in [1, "E"]
 
     # set some things
@@ -35,7 +45,7 @@ def test_scalcout_reset():
     calc.channels.BB.input_value.put("testing")
     calc.calculation.put("A")
     calc.process_record.put(1)
-    time.sleep(SHORT_DELAY_FOR_EPICS_IOC_DATABASE_PROCESSING)
+    timed_pause()
     assert calc.channels.A.input_value.get() == v
     assert calc.channels.BB.input_value.get() == "testing"
     assert calc.calculation.get() == "A"
@@ -43,6 +53,7 @@ def test_scalcout_reset():
     assert calc.calculated_value_string.get() == str(v)
 
     calc.reset()
+    timed_pause()
     assert calc.description.get() == calc.prefix
     assert calc.calculation.get() == "0"
     assert calc.channels.A.input_value.get() == 0
@@ -51,15 +62,5 @@ def test_scalcout_reset():
     assert calc.calculated_value_string.get() == "0.00000"
 
     v1 = calc.calculated_value.get()
-    time.sleep(0.2)
+    timed_pause(0.2)
     assert v1 == calc.calculated_value.get()
-
-# -----------------------------------------------------------------------------
-# :author:    Pete R. Jemian
-# :email:     jemian@anl.gov
-# :copyright: (c) 2017-2022, UChicago Argonne, LLC
-#
-# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# -----------------------------------------------------------------------------
