@@ -1,6 +1,10 @@
+from enum import Enum
+
 import databroker._drivers.mongo_normalized
 import databroker._drivers.msgpack
 import intake
+import pandas
+import pyRestTable
 
 FIRST_DATA = "1995-01-01"
 LAST_DATA = "2100-12-31"
@@ -18,6 +22,21 @@ MONGO_CATALOG_CLASSES = (
 )
 MAX_EPICS_STRINGOUT_LENGTH = 40
 
+
+class PRT_Table(pyRestTable.Table):
+    """Change the default from pyRestTable."""
+
+    def __repr__(self):
+        return str(self)
+
+
+class TableStyle(Enum):
+    """Describes what table style to use."""
+
+    pandas = pandas.DataFrame
+    pyRestTable = PRT_Table  # pyRestTable.Table
+
+
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
